[Libreoffice-commits] online.git: 2 commits - cypress_test/integration_tests
Tamás Zolnai (via logerrit)
logerrit at kemper.freedesktop.org
Thu Mar 12 11:06:47 UTC 2020
cypress_test/integration_tests/mobile/calc/apply_font_spec.js | 12 +++++++++-
cypress_test/integration_tests/mobile/writer/apply_font_spec.js | 12 +++++++++-
cypress_test/integration_tests/mobile/writer/insert_object_spec.js | 2 -
3 files changed, 23 insertions(+), 3 deletions(-)
New commits:
commit 9ebdf2329a722fbf24ecedcb38896b6d273f3732
Author: Tamás Zolnai <tamas.zolnai at collabora.com>
AuthorDate: Wed Mar 11 22:21:57 2020 +0100
Commit: Tamás Zolnai <tamas.zolnai at collabora.com>
CommitDate: Thu Mar 12 12:06:42 2020 +0100
cypress: mobile: replace contains() with .should('have.text',...)
It seems contains does not mean a retry functionality
which tries to find the item in the given time window.
Change-Id: Ib26a5d84a1dacbddcb56dec6fd4a0901ba7d2295
Reviewed-on: https://gerrit.libreoffice.org/c/online/+/90351
Tested-by: Jenkins CollaboraOffice <jenkinscollaboraoffice at gmail.com>
Reviewed-by: Tamás Zolnai <tamas.zolnai at collabora.com>
diff --git a/cypress_test/integration_tests/mobile/writer/insert_object_spec.js b/cypress_test/integration_tests/mobile/writer/insert_object_spec.js
index ca195481f..0604d992f 100644
--- a/cypress_test/integration_tests/mobile/writer/insert_object_spec.js
+++ b/cypress_test/integration_tests/mobile/writer/insert_object_spec.js
@@ -50,7 +50,7 @@ describe('Insert objects via insertion wizard.', function() {
.should('exist');
cy.get('.loleaflet-annotation-content.loleaflet-dont-break')
- .contains('some text');
+ .should('have.text', 'some text');
});
it('Insert default table.', function() {
commit e7a267d4c5a5416b19e8cf5af7581d450401d9c7
Author: Tamás Zolnai <tamas.zolnai at collabora.com>
AuthorDate: Wed Mar 11 22:20:30 2020 +0100
Commit: Tamás Zolnai <tamas.zolnai at collabora.com>
CommitDate: Thu Mar 12 12:06:30 2020 +0100
cypress: mobile: check the selected state of font combobox item.
Change-Id: I41a8fc86fbb1ad9bd5d48ac6d47c15e9322fa677
Reviewed-on: https://gerrit.libreoffice.org/c/online/+/90350
Tested-by: Tamás Zolnai <tamas.zolnai at collabora.com>
Reviewed-by: Tamás Zolnai <tamas.zolnai at collabora.com>
diff --git a/cypress_test/integration_tests/mobile/calc/apply_font_spec.js b/cypress_test/integration_tests/mobile/calc/apply_font_spec.js
index abd132d53..821b23748 100644
--- a/cypress_test/integration_tests/mobile/calc/apply_font_spec.js
+++ b/cypress_test/integration_tests/mobile/calc/apply_font_spec.js
@@ -1,4 +1,4 @@
/* global describe it cy beforeEach require afterEach*/
var helper = require('../../common/helper');
var calcHelper = require('./calc_helper');
@@ -118,6 +118,9 @@ describe('Apply font changes.', function() {
.contains('Linux Libertine G')
.click();
+ cy.get('.level-1[title="Font Name"] .mobile-wizard.ui-combobox-text.selected')
+ .should('have.text', 'Linux Libertine G');
+
cy.get('#mobile-wizard-back')
.click();
@@ -144,6 +147,13 @@ describe('Apply font changes.', function() {
.contains('14')
.click();
+ if (Cypress.env('LO_CORE_VERSION') === 'master')
+ cy.get('.level-1[title="Font Size"] .mobile-wizard.ui-combobox-text.selected')
+ .should('have.text', '14 pt');
+ else
+ cy.get('.level-1[title="Font Size"] .mobile-wizard.ui-combobox-text.selected')
+ .should('have.text', '14');
+
cy.get('#mobile-wizard-back')
.click();
@@ -1,4 +1,4 @@
-/* global describe it cy beforeEach require afterEach*/
+/* global describe it cy beforeEach require afterEach Cypress*/
var helper = require('../../common/helper');
var calcHelper = require('./calc_helper');
diff --git a/cypress_test/integration_tests/mobile/writer/apply_font_spec.js b/cypress_test/integration_tests/mobile/writer/apply_font_spec.js
index f266d804d..dc629f505 100644
--- a/cypress_test/integration_tests/mobile/writer/apply_font_spec.js
+++ b/cypress_test/integration_tests/mobile/writer/apply_font_spec.js
@@ -1,4 +1,4 @@
/* global describe it cy beforeEach require afterEach*/
var helper = require('../../common/helper');
var writerHelper = require('./writer_helper');
@@ -71,6 +71,9 @@ describe('Apply font changes.', function() {
.contains('Linux Libertine G')
.click();
+ cy.get('.level-1[title="Font Name"] .mobile-wizard.ui-combobox-text.selected')
+ .should('have.text', 'Linux Libertine G');
+
cy.get('#mobile-wizard-back')
.click();
@@ -97,6 +100,13 @@ describe('Apply font changes.', function() {
.contains('36')
.click();
+ if (Cypress.env('LO_CORE_VERSION') === 'master')
+ cy.get('.level-1[title="Font Size"] .mobile-wizard.ui-combobox-text.selected')
+ .should('have.text', '36 pt');
+ else
+ cy.get('.level-1[title="Font Size"] .mobile-wizard.ui-combobox-text.selected')
+ .should('have.text', '36');
+
cy.get('#mobile-wizard-back')
.click();
More information about the Libreoffice-commits
@@ -1,4 +1,4 @@
-/* global describe it cy beforeEach require afterEach*/
+/* global describe it cy beforeEach require afterEach Cypress*/
var helper = require('../../common/helper');
var writerHelper = require('./writer_helper');
mailing list